@@ -1,4 +1,4 @@
-//@line 45 "/usr/obj/i386/xulrunner-1.9.2.18/mozilla-1.9.2/toolkit/mozapps/downloads/content/downloads.js"
+//@line 45 "/usr/ports/pobj/xulrunner-1.9.2.25/mozilla-1.9.2/toolkit/mozapps/downloads/content/downloads.js"
 
 ////////////////////////////////////////////////////////////////////////////////
 //// Globals
@@ -246,7 +246,7 @@ function openDownload(aDownload)
       dontAsk = !pref.getBoolPref(PREF_BDM_ALERTONEXEOPEN);
     } catch (e) { }
 
-//@line 306 "/usr/obj/i386/xulrunner-1.9.2.18/mozilla-1.9.2/toolkit/mozapps/downloads/content/downloads.js"
+//@line 306 "/usr/ports/pobj/xulrunner-1.9.2.25/mozilla-1.9.2/toolkit/mozapps/downloads/content/downloads.js"
 
     if (!dontAsk) {
       var strings = document.getElementById("downloadStrings");
@@ -475,11 +475,11 @@ let gDownloadObserver = {
         }
         break;
       case "browser-lastwindow-close-granted":
-//@line 535 "/usr/obj/i386/xulrunner-1.9.2.18/mozilla-1.9.2/toolkit/mozapps/downloads/content/downloads.js"
+//@line 535 "/usr/ports/pobj/xulrunner-1.9.2.25/mozilla-1.9.2/toolkit/mozapps/downloads/content/downloads.js"
         if (gDownloadManager.activeDownloadCount == 0) {
           setTimeout(gCloseDownloadManager, 0);
         }
-//@line 539 "/usr/obj/i386/xulrunner-1.9.2.18/mozilla-1.9.2/toolkit/mozapps/downloads/content/downloads.js"
+//@line 539 "/usr/ports/pobj/xulrunner-1.9.2.25/mozilla-1.9.2/toolkit/mozapps/downloads/content/downloads.js"
         break;
     }
   }
@@ -1115,7 +1115,6 @@ function buildDownloadList(aForceBuild)
   gBuilder = setTimeout(function() {
     // Start building the list and select the first item
     stepListBuilder(1);
-    gDownloadsView.selectedIndex = 0;
 
     // We just tried to add a single item, so we probably need to enable
     updateClearListButton();
